#!/usr/bin/python3
# -*- coding: utf-8 -*-

# url_read.py file is part of slpkg.

# Copyright 2014-2022 Dimitris Zlatanidis <d.zlatanidis@gmail.com>
# All rights reserved.

# Slpkg is a user-friendly package manager for Slackware installations

# https://gitlab.com/dslackw/slpkg

# Slpkg is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


import urllib3

from slpkg.__metadata__ import MetaData as _meta_


class URL:
    """Urls reading class
    """
    def __init__(self, link):
        self.link = link
        self.meta = _meta_
        self.red = _meta_.color["RED"]
        self.endc = _meta_.color["ENDC"]
        if self.meta.http_proxy:
            self.http = urllib3.ProxyManager(self.meta.http_proxy)
        else:
            self.http = urllib3.PoolManager()

    def get_request(self):
        """Open url and read
        """
        try:
            f = self.http.request('GET', self.link)
            return f.data.decode("utf-8", "ignore")
        except urllib3.exceptions.NewConnectionError:
            print(f"\n{self.red}Can't read the file "
                  f"'{self.link.split('/')[-1]}'{self.endc}")
            return " "



#!/usr/bin/python3
# -*- coding: utf-8 -*-

# checksum.py file is part of slpkg.

# Copyright 2014-2022 Dimitris Zlatanidis <d.zlatanidis@gmail.com>
# All rights reserved.

# Slpkg is a user-friendly package manager for Slackware installations

# https://gitlab.com/dslackw/slpkg

# Slpkg is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


from slpkg.md5sum import md5
from slpkg.messages import Msg
from slpkg.__metadata__ import MetaData as _meta_


def check_md5(pkg_md5, src_file):
    """MD5 Checksum
    """
    msg = Msg()
    red = _meta_.color["RED"]
    green = _meta_.color["GREEN"]
    endc = _meta_.color["ENDC"]
    if _meta_.checkmd5 in ["on", "ON"]:
        print()
        md5s = md5(src_file)
        if pkg_md5 != md5s:
            msg.template(78)
            print(f"| MD5SUM check for {src_file.split('/')[-1]}"
                  f" [ {red}FAILED{endc} ]")
            msg.template(78)
            print(f"| Expected: {pkg_md5}")
            print(f"| Found: {md5s}")
            msg.template(78)
            print()
            if not msg.answer() in ["y", "Y"]:
                raise SystemExit()
        else:
            msg.template(78)
            print(f"| MD5SUM check for {src_file.split('/')[-1]}"
                  f" [ {green}PASSED{endc} ]")
            msg.template(78)
        print()   # new line after pass checksum



#!/usr/bin/python3
# -*- coding: utf-8 -*-

# setup.py file is part of slpkg.

# Copyright 2014-2022 Dimitris Zlatanidis <d.zlatanidis@gmail.com>
# All rights reserved.

# Slpkg is a user-friendly package manager for Slackware installations

# https://gitlab.com/dslackw/slpkg

# Slpkg is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


import os
import time
from slpkg.__metadata__ import MetaData as _meta_

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

docs_requires = []
tests_requires = []
install_requires = []
optional_requires = [
    "pythondialog>=3.5.1",
    "pygraphviz>=1.3.1"
]

# Non-Python/non-PyPI optional dependencies:
# ascii diagram: graph-easy (available from SBo repository)


def print_logo():
    """print slpkg logo"""
    logo_fname = os.path.join(os.path.dirname(__file__), 'logo.txt')
    with open(logo_fname, 'rb') as f:
        logo = f.read().decode('utf-8')
        print(logo)
        time.sleep(0.5)


print_logo()


setup(
    name="slpkg",
    packages=["slpkg", "slpkg/sbo", "slpkg/pkg", "slpkg/slack",
              "slpkg/binary"],
    scripts=["bin/slpkg"],
    version=_meta_.__version__,
    description="Package manager for Slackware installations",
    long_description=open("README.md").read(),
    keywords=["slackware", "slpkg", "upgrade", "install", "remove",
              "view", "slackpkg", "tool", "build"],
    author=_meta_.__author__,
    author_email=_meta_.__email__,
    url="https://dslackw.gitlab.io/slpkg/",
    package_data={"": ["LICENSE", "README.md", "CHANGELOG"]},
    data_files=[("man/man8", ["man/slpkg.8"]),
                ("/etc/bash_completion.d", ["conf/slpkg.bash-completion"]),
                ("/etc/fish/completions", ["conf/slpkg.fish"])],
    install_requires=install_requires,
    extras_require={
        "optional": optional_requires,
        "docs": docs_requires,
        "tests": tests_requires,
    },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: POSIX :: Linux",
        "Operating System :: Unix",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Unix Shell",
        "Topic :: Software Development :: Build Tools",
        "Topic :: System :: Archiving :: Packaging",
        "Topic :: System :: Software Distribution",
        "Topic :: System :: Installation/Setup",
        "Topic :: System :: Systems Administration",
        "Topic :: System :: Software Distribution",
        "Topic :: Utilities"],
    python_requires=">=3.7"
)



#!/usr/bin/python3
# -*- coding: utf-8 -*-

# checks.py file is part of slpkg.

# Copyright 2014-2022 Dimitris Zlatanidis <d.zlatanidis@gmail.com>
# All rights reserved.

# Slpkg is a user-friendly package manager for Slackware installations

# https://gitlab.com/dslackw/slpkg

# Slpkg is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


from slpkg.messages import Msg
from slpkg.arguments import usage
from slpkg.init import Initialization
from slpkg.__metadata__ import MetaData as _meta_


class Updates:
    """Checking for news in ChangeLog.txt
    """
    def __init__(self, repo):
        self.repo = repo
        self.meta = _meta_
        self.green = _meta_.color["GREEN"]
        self.endc = _meta_.color["ENDC"]
        self.msg = Msg()
        self.check = 2
        self.st = ""
        self.count_repo = 0
        self.count_news = 0
        self._init = Initialization(True)
        self.all_repos = {
            "slack": self._init.slack,
            "sbo": self._init.sbo,
            "rlw": self._init.rlw,
            "alien": self._init.alien,
            "slacky": self._init.slacky,
            "conrad": self._init.conrad,
            "slonly": self._init.slonly,
            "ktown": self._init.ktown,
            "multi": self._init.multi,
            "slacke": self._init.slacke,
            "salix": self._init.salix,
            "slackl": self._init.slackl,
            "rested": self._init.rested,
            "msb": self._init.msb,
            "csb": self._init.csb,
            "connos": self._init.msb,
            "mles": self._init.mles
        }

    def status_bar(self):
        """Top view bar status
        """
        self.msg.template(78)
        print("| Repository         Status")
        self.msg.template(78)

    def run(self):
        """Run and check if new in ChangeLog.txt
        """
        if (self.repo in self.meta.default_repositories and
                self.repo in self.meta.repositories):
            try:
                self.check = self.all_repos[self.repo]()
            except OSError:
                usage(self.repo, 1)
        elif self.repo in self.meta.repositories:
            self.check = self._init.custom(self.repo)
        else:
            usage(self.repo, 1)
        self.status_bar()
        self.status()
        self.print_status(self.repo)
        self.summary()

    def ALL(self):
        """Check ALL enabled repositories ChangeLogs
        """
        self.status_bar()
        for repo in self.meta.repositories:
            if repo in self.meta.default_repositories:
                try:
                    self.check = self.all_repos[repo]()
                except OSError:
                    usage(self.repo, 1)
            elif repo in self.meta.repositories:
                self.check = self._init.custom(repo)
            self.status()
            self.print_status(repo)
        self.summary()

    def status(self):
        """Set messages
        """
        self.count_repo += 1
        if self.check == 1:
            self.count_news += 1
            self.st = f"{self.green}News in ChangeLog.txt{self.endc}"
        elif self.check == 0:
            self.st = "No changes in ChangeLog.txt"

    def print_status(self, repo):
        """Print status
        """
        print(f"  {repo}{' ' * (19 - len(repo))}{self.st}")

    def summary(self):
        """Print summary
        """
        print("\nSummary")
        print("=" * 79)
        cmd = "All repositories are updated."
        if self.count_repo == 1:
            cmd = "Repository is updated."
        if self.count_news > 0:
            cmd = "Run the command 'slpkg update'."
        print(f"From {self.count_repo} repositories need"
              f" {self.count_news} updating. {cmd}", end="\n")



import unittest
from slpkg.md5sum import md5


class TestMd5(unittest.TestCase):

    def test_md5_superuser(self):
        """Testing checksum for superuser.py file
        """
        result = md5('test_file_size.py')
        self.assertEqual(result, "e3e7b72be80efc922b0e1f1cd409a417")

    def test_md5_security(self):
        """Testing checksum for security.py file
        """
        result = md5('test_units.py')
        self.assertEqual(result, "58a694171449e923414e3e3339a0097e")


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python3
# -*- coding: utf-8 -*-

# superuser.py file is part of slpkg.

# Copyright 2014-2022 Dimitris Zlatanidis <d.zlatanidis@gmail.com>
# All rights reserved.

# Slpkg is a user-friendly package manager for Slackware installations

# https://gitlab.com/dslackw/slpkg

# Slpkg is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


import os
import getpass


def s_user():
    """Check for root user
    """
    if getpass.getuser() != "root":
        raise SystemExit("\nslpkg: Error: Must have root privileges\n")


def virtual_env():
    """Check if a virtual enviroment exists
    """
    if "VIRTUAL_ENV" in os.environ.keys():
        raise SystemExit("\nslpkg: Error: Please exit from virtual "
                         "environment first\n")



#!/usr/bin/python3
# -*- coding: utf-8 -*-

# grep_md5.py file is part of slpkg.

# Copyright 2014-2022 Dimitris Zlatanidis <d.zlatanidis@gmail.com>
# All rights reserved.

# Slpkg is a user-friendly package manager for Slackware installations

# https://gitlab.com/dslackw/slpkg

# Slpkg is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


from slpkg.slack.mirrors import mirrors

from slpkg.url_read import URL
from slpkg.__metadata__ import MetaData as _meta_


def pkg_checksum(binary, repo):
    """Return checksum from CHECKSUMS.md5 file by repository
    """
    md5 = "None"
    if repo == "slack_patches" and _meta_.slack_rel == "stable":
        CHECKSUMS_md5 = URL(mirrors("CHECKSUMS.md5", "patches/")).get_request()
    elif repo == "slack_patches" and _meta_.slack_rel == "current":
        CHECKSUMS_md5 = URL(mirrors("CHECKSUMS.md5", "")).get_request()
    elif repo == "slpkg":
        CHECKSUMS_md5 = URL(_meta_.CHECKSUMS_link).get_request()
    else:
        lib = f"{_meta_.lib_path}{repo}_repo/CHECKSUMS.md5"
        f = open(lib, "r")
        CHECKSUMS_md5 = f.read()
        f.close()
    for line in CHECKSUMS_md5.splitlines():
        if line.endswith(f"/{binary}"):
            md5 = line.split()[0]
    return md5



#!/usr/bin/python3
# -*- coding: utf-8 -*

# installed.py file is part of slpkg.

# Copyright 2014-2022 Dimitris Zlatanidis <d.zlatanidis@gmail.com>
# All rights reserved.

# Slpkg is a user-friendly package manager for Slackware installations

# https://gitlab.com/dslackw/slpkg

# Slpkg is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


from slpkg.pkg.find import find_package

from slpkg.splitting import split_package
from slpkg.__metadata__ import MetaData as _meta_


class GetFromInstalled:
    """Find and return version and package name from
    already installed packages
    """
    def __init__(self, package):
        self.package = package
        self.meta = _meta_
        self.files = find_package(f"{self.package}-", self.meta.pkg_path)
        self.find = ""
        for file in self.files:
            if split_package(file)[0] == self.package:
                self.find = file

    def version(self):
        """Return version from installed packages
        """
        if self.find:
            return split_package(self.find)[1]
        return self.find

    def name(self):
        """Return installed package name
        """
        if self.find:
            return self.package
        return self.find



#!/usr/bin/python3
# -*- coding: utf-8 -*-

# clean.py file is part of slpkg.

# Copyright 2014-2022 Dimitris Zlatanidis <d.zlatanidis@gmail.com>
# All rights reserved.

# Slpkg is a user-friendly package manager for Slackware installations

# https://gitlab.com/dslackw/slpkg

# Slpkg is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


import os
import shutil


class Clean:
    """Clean all data like man page, log files, PACKAGES.TXT and
    configuration files. This is useful if "slpkg" installed via
    "pip" because pip uninstalls only Python packages and script
    and not data. So if uninstall with "# pip uninstall slpkg" after
    run "# python clean.py" to remove all data and configuration files.
    NOTE: Run this script as root."""
    def __init__(self):
        self.files = [
            "/usr/man/man8/slpkg.8.gz",
            "/etc/bash_completion.d/slpkg.bash-completion",
            "/etc/fish/completions/slpkg.fish"
        ]
        self.dirs = [
            "/etc/slpkg/",
            "/var/log/slpkg/",
            "/var/lib/slpkg/",
            "/tmp/slpkg/"
        ]

    def start(self):
        for f in self.files:
            if os.path.isfile(f):
                print(f"Remove file --> {f}")
                os.remove(f)
        for d in self.dirs:
            if os.path.exists(d):
                print(f"Remove directory --> {d}")
                shutil.rmtree(d)


if __name__ == "__main__":
    clean = Clean()
    clean.start()
